@@ -24,7 +24,7 @@
 //!   - Leverage feature flags to keep to one active branch
 //!   - Being under [WG-CLI](https://github.com/rust-cli/team/) to increase the bus factor
 //! - We follow semver and will wait about 6-9 months between major breaking changes
-//! - We will support the last two minor Rust releases (MSRV, currently 1.60.0)
+//! - We will support the last two minor Rust releases (MSRV, currently 1.70.0)
 //!
 //! While these aspirations can be at odds with fast build times and low binary
 //! size, we will still strive to keep these reasonable for the flexibility you
@@ -41,9 +41,10 @@
 //! *(See also [feature flag reference][_features])*
 //!
 //! Then define your CLI in `main.rs`:
-#![cfg_attr(not(feature = "derive"), doc = " ```ignore")]
-#![cfg_attr(feature = "derive", doc = " ```no_run")]
+//! ```rust
+//! # #[cfg(feature = "derive")] {
 #![doc = include_str!("../examples/demo.rs")]
+//! # }
 //! ```
 //!
 //! And try it out:
@@ -61,6 +62,7 @@
 //! - [clap_complete](https://crates.io/crates/clap_complete) for shell completion support
 //!
 //! CLI Helpers
+//! - [cio](https://crates.io/crates/clio) for reading/writing to files specified as arguments
 //! - [clap-verbosity-flag](https://crates.io/crates/clap-verbosity-flag)
 //! - [clap-cargo](https://crates.io/crates/clap-cargo)
 //! - [concolor-clap](https://crates.io/crates/concolor-clap)
@@ -94,30 +96,7 @@
 // Breaks up parallelism that clarifies intent
 #![allow(clippy::collapsible_else_if)]
 
-#[cfg(not(feature = "std"))]
-compile_error!("`std` feature is currently required to build `clap`");
-
-pub use crate::builder::ArgAction;
-pub use crate::builder::Command;
-pub use crate::builder::ValueHint;
-pub use crate::builder::{Arg, ArgGroup};
-pub use crate::parser::ArgMatches;
-#[cfg(feature = "color")]
-pub use crate::util::color::ColorChoice;
-#[cfg(not(feature = "color"))]
-#[allow(unused_imports)]
-pub(crate) use crate::util::color::ColorChoice;
-pub use crate::util::Id;
-
-/// Command Line Argument Parser Error
-///
-/// See [`Command::error`] to create an error.
-///
-/// [`Command::error`]: crate::Command::error
-pub type Error = crate::error::Error<crate::error::DefaultFormatter>;
-
-pub use crate::derive::{Args, CommandFactory, FromArgMatches, Parser, Subcommand, ValueEnum};
-
+pub use clap_builder::*;
 #[cfg(feature = "derive")]
 #[doc(hidden)]
 pub use clap_derive::{self, *};
@@ -132,27 +111,3 @@ pub mod _faq;
 pub mod _features;
 #[cfg(feature = "unstable-doc")]
 pub mod _tutorial;
-
-#[doc(hidden)]
-pub mod __macro_refs {
-    #[cfg(any(feature = "derive", feature = "cargo"))]
-    #[doc(hidden)]
-    pub use once_cell;
-}
-
-#[macro_use]
-#[allow(missing_docs)]
-mod macros;
-
-mod derive;
-
-pub mod builder;
-pub mod error;
-pub mod parser;
-
-mod mkeymap;
-mod output;
-mod util;
-
-const INTERNAL_ERROR_MSG: &str = "Fatal internal error. Please consider filing a bug \
-                                  report at https://github.com/clap-rs/clap/issues";
